#!/bin/sh

# This Script is to be installed on Linux Systems and it should be called 
# from the postinstall script.  The purpose  of this script is to determine 
# if the Linux OS is Redhat 7.x or not.  If the Linux OS is a RedHat 7.x 
# system, we will create a file called /usr/markvision/etc/redhat7 that will 
# be used by lexprt.  If this file exists, then when creating queues, lexprt 
# will create the spool directory and set the ownership to be "lp" otherwise 
# "daemon".  RedHat 7's LPRng  requires the Spool Directory to be owned by "lp".

redhat7_file=/usr/markvision/etc/redhat7
write_file()
{
cat > ${redhat7_file} <<EOL
This file is created by the /usr/markvision/bin/linux-version.sh
script.  The purpose of this file is to determine if the Linux OS
is Redhat 7 or not. If this file exists, then when creating queues,
lexprt will create the spool directory and set the ownership to be
"lp" otherwise "daemon".  RedHat 7's LPRng requires the Spool
Directory to be owned by "lp". Other Linux Distributions require the
directory to be owned by "daemon".
EOL
}

remove_file()
{
if [ -f "${redhat7_file}" ]; then
   rm -rf "${redhat7_file}"
   if [ "$?" != "0" ]; then
      printf "\nError Removing ${redhat7_file}.\n" 
      printf "Please remove the file ${redhat7_file} manually.\n\n"
      exit 1;
   fi
fi
}

# Make user the user is root
user=`/usr/bin/whoami`
if [ "$user" != "root" ]; then
   echo
   echo "You must be Root to run $0."
   echo
   exit 0;
fi


# Checking to see if this a SuSE System.
if [ -f /etc/SuSE-release ]; then
   printf "\nSuSE Linux Distribution.\n\n"
   exit 0;
fi

# Checking to see if this a TurboLinux System.
if [ -f /etc/turbolinux-release ]; then
   printf "\nTurboLinux Distribution.\n\n"
   exit 0;
fi

# Checking to see if this a TurboLinux System.
if [ -f /etc/redhat-release ]; then
   VER="`cat /etc/redhat-release | awk '{print $5}'`"
   printf "\nRedHat [ ${VER} ] Distribution.\n\n"
   expr ${VER} \>= 7.0 >/dev/null
   RC=$?
   if [ "${RC}" != "1" ]; then
      write_file
      exit 0
   else
      exit 0
   fi
fi

# If we make it this far, we cannot determine the Linux Distribution.
# So we must ask.

printf "\n\nEnhanced Printer Drivers needs to know which Linux Distribution\n"
printf "this is.  Please select one of the following by the Number\n"
printf "Associated with the Linux Distribution.\n\n"
printf "1.  Caldera OpenServer 2.4\n2.  RedHat Linux 6.2\n"
printf "3.  RedHat Linux 7.0,7.1\n4.  SuSE Linux 7.0,7.1,7.2\n"
printf "5.  TurboLinux 6.0,6.1\n\n"

run=true
while  $run
do
  printf "\nSelect a number 1-5 > "
  read userver
  case $userver in
 
  1) run=false
     printf "\nCaldera OpenServer Distribution.\n\n"
     remove_file
     printf "Done..\n\n"
     ;;
  2) run=false
     printf "\nRedHat [ 6.1,6.2 ] Distribution.\n\n"
     remove_file
     printf "Done..\n\n"
     ;;
  3) run=false
     write_file 
     printf "\nRedHat [ 7.0 ] Distribution.\n\n"
     printf "Done..\n\n"
     ;;
  4) run=false
     printf "\nSuSE Linux Distribution.\n\n"
     remove_file
     printf "Done..\n\n"
     ;;
  5) run=false
     printf "\nTurboLinux Distribution.\n\n"
     remove_file
     printf "Done..\n\n"
     ;;
  esac
done

exit 0
